/* SPDX-License-Identifier: GPL-2.0-or-later */
/*
 * Copyright (C) 2020 Verisilicon Inc.
 */

#ifndef __TRANSCODER_H__
#define __TRANSCODER_H__

#if !defined(__MICROBLAZE__)
#include <linux/types.h>
#include <linux/ioctl.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

enum TRANS_HDMA_DIR {
	RC2EP = 0,
	EP2RC = 1,
};

enum TRANS_HDMA_INT {
	POLL_EN = 0,
	INTE_EN = 1,
};

/* pcie bar region description */
struct bar_info {
	__u32 bar_num;
	__u64 bar_addr;
	__u32 bar_size;
};

/* hdma info description */
struct trans_pcie_hdma {
	__u32 size; /* transfer size */
	__u64 sar; /* source address 64 bits */
	__u64 dar; /* destination address 64 bits */
	__u32 dir; /* direction: RC2EP or RC2EP ,need rename to dir */
	__s32 fd; /* fd: owner of the ep address */
};

struct reg_desc {
	__u32 id; /* register index, starting from 0 */
	__u32 val; /* value */
};

struct mem_info {
	__s32 task_id; /* task id */
	__u64 phy_addr; /* physics address */    // alloc(out), free(in)
	__u32 size;                              // alloc only (and optional validation on free?)
    __s32 fd; /*device handle*/            // THIS IS UNNECESSARY
};

struct release_addr_t {
	__u32 pc_l; /* pc low val */
	__u32 pc_h; /* pc high val */
};

/* ep memory used information */
struct mem_used_info {
	__u32 s1_used;
	__u32 s1_free;
	__u32 s1_blk_used;
	__u32 s2_used;
	__u32 s2_free;
	__u32 s2_blk_used;
};

/* for vc8000d */
enum vcd_core_type {
	/* Decoder */
	HW_VC8000D = 0,
	HW_VC8000DJ,
	HW_BIGOCEAN,
	HW_VCMD,
	HW_MMU,
	HW_MMU_WR,
	HW_DEC400,
	HW_L2CACHE,
	HW_SHAPER,
	/* Encoder*/
	/* Auxiliary IPs */
	HW_NOC,
	HW_AXIFE,
	HW_AFBC,
	HW_CORE_MAX /* max number of cores supported */
};

enum vcd_codec_type {
	VC8000D_CLIENT_TYPE_H264_DEC = 1,
	VC8000D_CLIENT_TYPE_MPEG4_DEC,
	VC8000D_CLIENT_TYPE_JPEG_DEC,
	VC8000D_CLIENT_TYPE_PP,
	VC8000D_CLIENT_TYPE_VC1_DEC,
	VC8000D_CLIENT_TYPE_MPEG2_DEC,
	VC8000D_CLIENT_TYPE_VP6_DEC,
	VC8000D_CLIENT_TYPE_AVS_DEC,
	VC8000D_CLIENT_TYPE_RV_DEC,
	VC8000D_CLIENT_TYPE_VP8_DEC,
	VC8000D_CLIENT_TYPE_VP9_DEC,
	VC8000D_CLIENT_TYPE_HEVC_DEC,
	VC8000D_CLIENT_TYPE_ST_PP,
	VC8000D_CLIENT_TYPE_H264_MAIN10,
	VC8000D_CLIENT_TYPE_AVS2_DEC,
	VC8000D_CLIENT_TYPE_AV1_DEC,
	VC8000D_CLIENT_TYPE_BO_AV1_DEC,
	VC8000D_CLIENT_TYPE_MAX
};

#define CoreType vcd_core_type
enum MISC_IP_ID {
	F1_ID,
	F2_ID,
	F3_ID,
};
struct core_desc {
	__u32 id; /* id of the subsystem */
	__u32 type; /* type of core to be written */
	__u32 *regs; /* pointer to user registers */
	__u32 size; /* size of register space */
	__u32 reg_id; /* id of reigster to be read/written */
};

struct ip_desc {
	__u8 ip_id;
	struct core_desc core;
};

struct regsize_desc {
	__u32 slice; /* id of the slice */
	__u32 id; /* id of the subsystem */
	__u32 type; /* type of core to be written */
	__u32 size; /* iosize of the core */
};

struct core_param {
	__u32 slice; /* id of the slice */
	__u32 id; /* id of the subsystem */
	__u32 type; /* type of core to be written */
	__u32 size; /* iosize of the core */
	__u32 asic_id; /* asic id of the core */
};

struct subsys_desc {
	__u32 subsys_num; /* total subsystems count */
	__u32 subsys_vcmd_num; /* subsystems with vcmd */
};

struct axife_cfg {
	__u8 axi_rd_chn_num;
	__u8 axi_wr_chn_num;
	__u8 axi_rd_burst_length;
	__u8 axi_wr_burst_length;
	__u8 fe_mode;
	__u32 id;
};

struct apbfilter_cfg {
	__u32 nbr_mask_regs;
	__u32 mask_reg_offset;
	__u32 page_sel_addr;
	__u8 num_mode;
	__u8 mask_bits_per_reg;
	__u32 id; /* id of the subsystem */
	__u32 type; /* type of core to be written */
	__u32 has_apbfilter;
};

#define HW_ID_1_0_C 0x43421001
#define HW_ID_1_1_2 0x43421102

#define ANY_CMDBUF_ID 0xFFFF

#ifndef ASIC_SWREG_AMOUNT
#define ASIC_SWREG_AMOUNT 543 //from encswhwregister.h
#endif

/*maximum device nums */
#define MAX_DEVICE_CNT	40

/*these size need to be modified according to hw config.*/
#define ENCODER_REGISTER_SIZE ASIC_SWREG_AMOUNT
#define IM_REGISTER_SIZE ASIC_SWREG_AMOUNT
#define JPEG_ENCODER_REGISTER_SIZE ASIC_SWREG_AMOUNT

#define DEC400_REGISTER_SIZE 1600
#define MMU_REGISTER_SIZE 500
#define L2CACHE_REGISTER_SIZE 500
#define AXIFE_REGISTER_SIZE 500

/*module_type support*/


enum vcmd_module_type {
	VCMD_TYPE_ENCODER = 0,
	VCMD_TYPE_CUTREE,
	VCMD_TYPE_DECODER,
	VCMD_TYPE_JPEG_ENCODER,
	VCMD_TYPE_JPEG_DECODER,
	MAX_VCMD_TYPE
};

struct cmdbuf_mem_parameter {
	__u32 *virt_cmdbuf_addr;
	__u64 phy_cmdbuf_addr; //cmdbuf pool base physical address
	__u32 mmu_phy_cmdbuf_addr; //cmdbuf pool base mmu mapping address
	__u32 cmdbuf_total_size; //cmdbuf pool total size in bytes.
	__u16 cmdbuf_unit_size; //one cmdbuf size in bytes. all cmdbuf have same size.
	__u32 *virt_status_cmdbuf_addr;
	__u64 phy_status_cmdbuf_addr; //status cmdbuf pool base physical address
	__u32 mmu_phy_status_cmdbuf_addr; //status cmdbuf pool base mmu mapping address
	__u32 status_cmdbuf_total_size; //status cmdbuf pool total size in bytes.
	__u16 status_cmdbuf_unit_size; //one status cmdbuf size in bytes. all status cmdbuf have same size.
	__u64 base_ddr_addr; //for pcie interface, hw can only access phy_cmdbuf_addr-pcie_base_ddr_addr.
		//for other interface, this value should be 0?
};

struct config_parameter {
	__u16 module_type; //input vc8000e=0,cutree=1,vc8000d=2,jpege=3, jpegd=4
	__u16 vcmd_core_num; //output, how many vcmd cores are there with corresponding module_type.
	__u16 submodule_main_addr; //output,if submodule addr == 0xffff, this submodule does not exist.
	__u16 submodule_dec400_addr; //output ,if submodule addr == 0xffff, this submodule does not exist.
	__u16 submodule_L2Cache_addr; //output,if submodule addr == 0xffff, this submodule does not exist.
	__u16 submodule_MMU_addr
		[2]; //output,if submodule addr == 0xffff, this submodule does not exist.
	__u16 submodule_axife_addr
		[2]; //output,if submodule addr == 0xffff, this submodule does not exist.
	__u16 config_status_cmdbuf_id; // output , this status comdbuf save the all register values read in driver init.//used for analyse configuration in cwl.
	__u32 vcmd_hw_version_id;
};

/*need to consider how many memory should be allocated for status.*/
struct exchange_parameter {
	__u64 executing_time; //input ;executing_time=encoded_image_size*(rdoLevel+1)*(rdoq+1);
	__u16 module_type; //input input vc8000e=0,IM=1,vc8000d=2, jpege=3, jpegd=4
	__u16 cmdbuf_size; //input, reserve is not used; link and run is input.
	__u16 priority; //input,normal=0, high/live=1
	__u16 cmdbuf_id; //output, it is unique in driver.
	__u16 core_id; //just used for polling.
};

struct core_reserve_param {
	__u32 format; //codec format
	__u32 dec_path; //decoder path: path a, path b, path a+b
};
/* end for vc8000d */

enum {
	DEC_PATH_A = 1,
	DEC_PATH_B = 2,
	DEC_PATH_AB = 3,
	DEC_PATH_MAX
};

/* for vc8000e */
enum {
	CORE_VC8000E = 0,
	CORE_VC8000EJ = 1,
	CORE_CUTREE = 2,
	CORE_DEC400 = 3,
	CORE_MMU = 4,
	CORE_L2CACHE = 5,
	CORE_AXIFE = 6,
	CORE_APBFT = 7,
	CORE_MMU_1 = 8,
	CORE_AXIFE_1 = 9,
	CORE_MAX
};
//#define CORE_MAX  (CORE_MMU)

struct subsys_core_info {
	__u32 type_info;
	unsigned long offset[CORE_MAX];
	unsigned long regSize[CORE_MAX];
	int irq[CORE_MAX];
	char irq_name[CORE_MAX][32];
};

struct core_wait_out {
	__u32 job_id[4];
	__u32 irq_status[4];
	__u32 irq_num;
};
/* end for vc8000e */

/* for xav1 */
struct xav1_msg {
	__u16 slice;
	__u16 count;
	__u32 content[4];
};

struct xav1_wait_msg {
	__u16 slice;
	__u16 slot;
	__u32 content[4];
	__u32 timeout_ms;
};

struct xav1_slot {
	__u32 slice; // slice in (always)
	__u32 slot; // slice out on alloc, in on free
};

/* end for xav1 */

/* sn_perf */

#include "sn_perf_types.h"

typedef struct {
	__u32 ipId : 7;
	__u32 cmd : 2;
	__u32 arg : 13;
} sn_perf_cmd;

typedef struct {
	union {
		struct {
			__u32 slice : 1;
			__u32 ipId : 7;
			__u32 unitId : 5;
			__u32 type : 2;
			__u32 hwTsValid : 1;
		};
		__u32 bits;
	};
	__u32 hwTs;
	__u32 payload;
	union {
		__u32 name;
		char namec[4];
	};
	__u64 kernelTs;
} sn_perf_event;

typedef struct {
	__u32 count;
	__u32 timeoutMs;
	sn_perf_event events[];
} sn_perf_poll;

/* end for sn_perf */

// osal_queues

#if defined(USE_OSAL)
#include <common/osaltypes.h>
#endif

/* pcie submodule ioctl commands */
#define IOCTL_CMD_PCIE_MINNR 0x00
#define IOCTL_CMD_PCIE_MAXNR 0x01
#define SN_TRANX_GET_BARADDR _IOWR('k', 0x00, struct bar_info *)
#define SN_TRANX_SW_DDR_MAPPING _IOWR('k', 0x01, __u32 *)

/* hdma submodule ioctl commands */
#define IOCTL_CMD_HDMA_MINNR 0x02
#define IOCTL_CMD_HDMA_MAXNR 0x03
#define SN_TRANX_HDMA_TRANX_VIR _IOWR('k', 0x02, struct trans_pcie_hdma *)
#define SN_TRANX_HDMA_TRANX_PHY _IOWR('k', 0x03, struct trans_pcie_hdma *)

/* memory submodule ioctl commands */
#define IOCTL_CMD_MEM_MINNR 0x05
#define IOCTL_CMD_MEM_MAXNR 0x0a
#define SN_TRANX_MEM_GET_UTIL _IOWR('k', 0x05, struct mem_used_info *)
#define SN_TRANX_MEM_ALLOC _IOWR('k', 0x06, struct mem_info *)
#define SN_TRANX_MEM_FREE _IOWR('k', 0x07, struct mem_info *)
#define SN_TRANX_MEM_GET_TASKID _IOWR('k', 0x08, __s32 *)
#define SN_TRANX_MEM_FREE_TASKID _IOWR('k', 0x09, __s32 *)
#define SN_TRANX_MEM_ALLOC_HANDLE _IOWR('k', 0x0a, struct mem_info *)

/* vc8000e submodule ioctl commands */
#define IOCTL_CMD_VC8000E_MINNR 0x10
#define IOCTL_CMD_VC8000E_MAXNR 0x1c
#define HANTRO_IOCG_HWOFFSET _IOR('k', 0x10, unsigned long *)
#define HANTRO_IOCG_HWIOSIZE _IOR('k', 0x11, unsigned int *)
#define HANTRO_IOCH_ENC_RESERVE _IOR('k', 0x12, unsigned int *)
#define HANTRO_IOCH_ENC_RELEASE _IOR('k', 0x13, unsigned int *)
#define HANTRO_IOCG_CORE_NUM _IOR('k', 0x14, unsigned int *)
#define HANTRO_IOCG_CORE_INFO _IOR('k', 0x15, struct subsys_core_info *)
#define HANTRO_IOCG_CORE_WAIT _IOR('k', 0x16, unsigned int *)
#define HANTRO_IOCG_ANYCORE_WAIT _IOR('k', 0x17, struct core_wait_out *)
#define HANTRO_IOCH_GET_VCMD_ENABLE _IOWR('k', 0x18, unsigned long)
#define HANTRO_IOC_SOFT_RESET _IO('k', 0x19)
#define PWRTEST_IOC_VCE_RESET_KEEP _IO('k', 0x1a)
#define PWRTEST_IOC_VCE_RESET_RELEASE _IO('k', 0x1b)
#define HANTRO_IOC_SOFT_RESET_SLICE _IO('k', 0x1c)

/* vc8000d submodule ioctl commands */
#define IOCTL_CMD_VCD_MINNR 0x20
#define IOCTL_CMD_VCD_MAXNR 0x37
#define HANTRODEC_IOCGHWOFFSET _IOR('k', 0x20, unsigned long *)
#define HANTRODEC_IOCGHWIOSIZE _IOR('k', 0x21, struct regsize_desc *)
#define HANTRODEC_IOC_MC_OFFSETS _IOR('k', 0x22, unsigned long *)
#define HANTRODEC_IOC_MC_CORES _IOR('k', 0x23, unsigned int *)
#define HANTRODEC_IOCS_DEC_PUSH_REG _IOW('k', 0x24, struct core_desc *)
#define HANTRODEC_IOCH_DEC_RESERVE _IOWR('k', 0x25, struct core_reserve_param *)
#define HANTRODEC_IOCT_DEC_RELEASE _IO('k', 0x26)
#define HANTRODEC_IOCX_DEC_WAIT _IOWR('k', 0x27, struct core_desc *)
#define HANTRODEC_IOCS_DEC_PULL_REG _IOWR('k', 0x28, struct core_desc *)
#define HANTRODEC_IOCG_CORE_WAIT _IOR('k', 0x29, int *)
#define HANTRODEC_IOX_ASIC_ID _IOWR('k', 0x2a, struct core_param *)
#define HANTRODEC_IOCG_CORE_ID _IOR('k', 0x2b, unsigned long)
#define HANTRODEC_IOCS_DEC_WRITE_REG _IOW('k', 0x2c, struct core_desc *)
#define HANTRODEC_IOCS_DEC_READ_REG _IOWR('k', 0x2d, struct core_desc *)
#define HANTRODEC_IOX_ASIC_BUILD_ID _IOWR('k', 0x2e, __u32 *)
#define HANTRODEC_IOX_SUBSYS _IOWR('k', 0x2f, struct subsys_desc *)
#define HANTRODEC_IOCX_POLL _IO('k', 0x30)
#define HANTRODEC_DEBUG_STATUS _IO('k', 0x31)
#define HANTRODEC_IOCS_DEC_WRITE_APBFILTER_REG                                 \
	_IOW('k', 0x32, struct core_desc *)
#define HANTRODEC_IOC_APBFILTER_CONFIG _IOR('k', 0x33, struct apbfilter_cfg *)
#define HANTRODEC_IOC_AXIFE_CONFIG _IOR('k', 0x34, struct axife_cfg *)
#define HANTRODEC_IOC_SOFT_RESET _IO('k', 0x35)
#define PWRTEST_IOC_DEC_RESET_KEEP _IO('k', 0x36)
#define PWRTEST_IOC_DEC_RESET_RELEASE _IO('k', 0x37)

/* misc submodule ioctl commands */
#define IOCTL_CMD_HOST_IP_MINNR 0x40
#define IOCTL_CMD_HOST_IP_MAXNR 0x43
#define SN_TRANX_RD_REG _IOWR('k', 0x40, struct ip_desc *)
#define SN_TRANX_WR_REG _IOWR('k', 0x41, struct ip_desc *)
#define SN_TRANX_PULL_REGS _IOWR('k', 0x42, struct ip_desc *)
#define SN_TRANX_PUSH_REGS _IOWR('k', 0x43, struct ip_desc *)

/* Use 'k' as magic number */
#define HANTRO_VCMD_IOC_MAGIC 'k'
/*
 * S means "Set" through a ptr,
 * T means "Tell" directly with the argument value
 * G means "Get": reply by setting through a pointer
 * Q means "Query": response is on the return value
 * X means "eXchange": G and S atomically
 * H means "sHift": T and Q atomically
 */
#define IOCTL_CMD_VCMD_IP_MINNR 0x50
#define IOCTL_CMD_VCMD_IP_MAXNR 0x58
#define HANTRO_VCMD_IOCH_GET_CMDBUF_PARAMETER                                  \
	_IOWR(HANTRO_VCMD_IOC_MAGIC, 0x50, struct cmdbuf_mem_parameter *)
#define HANTRO_VCMD_IOCH_GET_CMDBUF_POOL_SIZE                                  \
	_IOWR(HANTRO_VCMD_IOC_MAGIC, 0x51, unsigned long)
#define HANTRO_VCMD_IOCH_SET_CMDBUF_POOL_BASE                                  \
	_IOWR(HANTRO_VCMD_IOC_MAGIC, 0x52, unsigned long)

#define HANTRO_VCMD_IOCH_GET_VCMD_PARAMETER                                    \
	_IOWR(HANTRO_VCMD_IOC_MAGIC, 0x53, struct config_parameter *)

#define HANTRO_VCMD_IOCH_RESERVE_CMDBUF                                        \
	_IOWR(HANTRO_VCMD_IOC_MAGIC, 0x54, struct exchange_parameter *)
#define HANTRO_VCMD_IOCH_LINK_RUN_CMDBUF                                       \
	_IOR(HANTRO_VCMD_IOC_MAGIC, 0x55, u16 *)
#define HANTRO_VCMD_IOCH_WAIT_CMDBUF _IOR(HANTRO_VCMD_IOC_MAGIC, 0x56, u16 *)
#define HANTRO_VCMD_IOCH_RELEASE_CMDBUF _IOR(HANTRO_VCMD_IOC_MAGIC, 0x57, u16 *)
#define HANTRO_VCMD_IOCH_POLLING_CMDBUF _IOR(HANTRO_VCMD_IOC_MAGIC, 0x58, u16 *)

#define HANTRO_VCMD_IOC_MAXNR 0x58

/* xabr submodule ioctl commands */
#define IOCTL_CMD_XABR_MINNR 0x60
#define IOCTL_CMD_XABR_MAXNR 0x68
#define XABR_IOCTL_READ_REG _IOR('k', 0x60, struct core_desc *)
#define XABR_IOCTL_WRITE_REG _IOWR('k', 0x61, struct core_desc *)
#define XABR_IOCTL_WAIT_DONE _IOR('k', 0x62, unsigned int *)
#define XABR_IOCH_RESERVE _IO('k', 0x63)
#define XABR_IOCH_RELEASE _IO('k', 0x64)
#define XABR_IOCTL_SOFT_RESET _IOWR('k', 0x65, unsigned int *)
#define PWRTEST_XABR_RESET_KEEP _IOR('k', 0x66, unsigned int *)
#define PWRTEST_XABR_RESET_RELEASE _IOR('k', 0x67, unsigned int *)
#define XABR_IOCTL_TWO_SLICE_SOFT_RESET _IO('k', 0x68)

/* xav1 enc submodule ioctl commands */
#define IOCTL_CMD_XAV1_ENC_MINNR 0x70
#define IOCTL_CMD_XAV1_ENC_MAXNR 0x7b
#define XAV1_ENC_IOCTL_READ_REG _IOWR('k', 0x70, struct core_desc *)
#define XAV1_ENC_IOCTL_WRITE_REG _IOW('k', 0x71, struct core_desc *)
#define XAV1_ENC_IOCTL_ALLOC_SLOT _IOWR('k', 0x72, struct xav1_slot *)
#define XAV1_ENC_IOCTL_FREE_SLOT _IOW('k', 0x73, struct xav1_slot *)
#define XAV1_ENC_IOCTL_SEND_MSG _IOW('k', 0x74, struct xav1_msg *)
#define XAV1_ENC_IOCTL_WAIT_MSG _IOWR('k', 0x75, struct xav1_wait_msg *)
#define XAV1_ENC_IOCTL_WHOLE_SOFT_RESET _IOWR('k', 0x76, unsigned int *)
#define XAV1_ENC_IOCTL_BOOT_LOCK_ACQUIRE _IO('k', 0x77)
#define XAV1_ENC_IOCTL_BOOT_LOCK_RELEASE _IO('k', 0x78)
#define PWRTEST_XAV1_RESET_KEEP _IOR('k', 0x79, unsigned int *)
#define PWRTEST_XAV1_RESET_RELEASE _IOR('k', 0x7a, unsigned int *)
#define XAV1_ENC_IOCTL_TWO_SLICE_SOFT_RESET _IO('k', 0x7b)

/* riscv submodule ioctl commands */
#define IOCTL_CMD_RISCV_IP_MINNR 0x80
#define IOCTL_CMD_RISCV_IP_MAXNR 0x89
#define RISCV_0_IOCS_POWER_ON _IOWR('k', 0x80, struct ip_desc *)
#define RISCV_0_IOCS_POWER_OFF _IOWR('k', 0x81, struct ip_desc *)
#define RISCV_0_IOCS_SOFT_RESET _IOWR('k', 0x82, struct ip_desc *)
#define RISCV_0_IOCS_RESET_REALEASE _IOWR('k', 0x83, struct ip_desc *)
#define RISCV_0_IOCS_RELEASE_ADDR _IOWR('k', 0x84, struct ip_desc *)
#define RISCV_1_IOCS_POWER_ON _IOWR('k', 0x85, struct ip_desc *)
#define RISCV_1_IOCS_POWER_OFF _IOWR('k', 0x86, struct ip_desc *)
#define RISCV_1_IOCS_SOFT_RESET _IOWR('k', 0x87, struct ip_desc *)
#define RISCV_1_IOCS_RESET_REALEASE _IOWR('k', 0x88, struct ip_desc *)
#define RISCV_1_IOCS_RELEASE_ADDR _IOWR('k', 0x89, struct ip_desc *)

/* gpu submodule ioctl commands */
#define IOCTL_CMD_GPU_MINNR 0x90
#define IOCTL_CMD_GPU_MAXNR          0x9f
#define IOCTL_GCHAL_INTERFACE            _IOWR('k', 0x99, void *)
#define IOCTL_GCHAL_PROFILER_INTERFACE   _IOWR('k', 0x9a, void *)
#define IOCTL_GCHAL_TERMINATE            _IOWR('k', 0x9b, void *)
#define IOCTL_GCHAL_GPU2D_SOFT_RESET     _IO('k', 0x90)
#define IOCTL_GCHAL_VIP_SOFT_RESET       _IO('k', 0x91)
#define PWRTEST_GPU_RESET_KEEP           _IO('k', 0x92)
#define PWRTEST_GPU_RESET_RELEASE        _IO('k', 0x93)
#define PWRTEST_VIP_RESET_KEEP           _IO('k', 0x94)
#define PWRTEST_VIP_RESET_RELEASE        _IO('k', 0x95)


/* perfcollector submodule */

#define IOCTL_CMD_PERF_MINNR 0xa0
#define IOCTL_CMD_PERF_MAXNR 0xa1
#define IOCTL_PERF_CMD _IOW('k', 0xa0, sn_perf_cmd *)
#define IOCTL_PERF_POLL _IOWR('k', 0xa1, sn_perf_poll *)

/* osal queues submodule */

#if defined(USE_OSAL)
typedef struct osal_ioctl_header {
	osal_accelerator accel;
	uint64_t         handle;
} osal_ioctl_header;

typedef osal_ioctl_header ma_create_ctx;
typedef osal_ioctl_header ma_delete_ctx;

typedef struct osal_submit {
	osal_ioctl_header header;
	osal_command_list cmdList;
} osal_submit;

typedef struct osal_wait {
	osal_ioctl_header  header;
	uint32_t           cmdId;
	uint32_t           timeoutMs;
	osal_response_list respList;
} osal_wait;

#define IOCTL_MA_CREATE_CTX _IOWR('k', 0xb0, ma_create_ctx*)
#define IOCTL_MA_DELETE_CTX _IOWR('k', 0xb1, ma_delete_ctx*)
#define IOCTL_MA_SUBMIT_CMD _IOWR('k', 0xb2, osal_submit*)
#define IOCTL_MA_WAIT_RSP   _IOWR('k', 0xb3, osal_wait*)

#define IOCTL_CMD_MA_MINNR 0xb0
#define IOCTL_CMD_MA_MAXNR 0xb3
#endif

/* global module */
#define IOCTL_CMD_GLOBAL_MINNR 0xc0
#define IOCTL_CMD_GLOBAL_MAXNR 0xc0
#define IOCTL_ALL_IP_SOFT_RESET _IO('k', 0xc0)

#define TRANS_MAXNR 0xc0

#ifdef __cplusplus
}
#endif

#endif /*  __TRANSCODER_H__*/
